snapshot_provider
:   The name of the cloud provider which should be used to create snapshots.
    Required when the `snapshot` value is specified for
    `backup_method`. Supported values: `gcp`.

    Scope: Global/Server/Model.
